@@ -6,12 +6,24 @@ Grouping of all errors that can occur in genesis.
 """
 
 
-class ConnectionTimeoutError(Exception):
+class ConnectionError(ConnectionError):
+    """exception created to group all connection errors."""
+
+    ...
+
+
+class ConnectionTimeoutError(ConnectionError):
     """Occurs when the connection does not occur within the established timeout."""
 
     ...
 
 
+class SessionGoneAway(Exception):
+    """Occurs when the session has already received a hangup."""
+
+    ...
+
+
 class AuthenticationError(ValueError):
     """It happens when we have a problem during authentication."""
 
